==> xchat-2.4.1.tar.bz2: xchat-2.4.1/src/common/textenums.h <==
/* this file is auto generated, edit textevents.in instead! */

enum
{
	XP_TE_ADDNOTIFY,		XP_TE_BANLIST,
	XP_TE_BANNED,		XP_TE_BEEP,
	XP_TE_CHANGENICK,		XP_TE_CHANACTION,
	XP_TE_HCHANACTION,		XP_TE_CHANBAN,
	XP_TE_CHANDATE,		XP_TE_CHANDEHOP,
	XP_TE_CHANDEOP,		XP_TE_CHANDEVOICE,
	XP_TE_CHANEXEMPT,		XP_TE_CHANHOP,
	XP_TE_CHANINVITE,		XP_TE_CHANLISTHEAD,
	XP_TE_CHANMSG,		XP_TE_CHANMODEGEN,
	XP_TE_CHANMODES,		XP_TE_HCHANMSG,
	XP_TE_CHANNOTICE,		XP_TE_CHANOP,
	XP_TE_CHANRMEXEMPT,		XP_TE_CHANRMINVITE,
	XP_TE_CHANRMKEY,		XP_TE_CHANRMLIMIT,
	XP_TE_CHANSETKEY,		XP_TE_CHANSETLIMIT,
	XP_TE_CHANUNBAN,		XP_TE_CHANVOICE,
	XP_TE_CONNECTED,		XP_TE_CONNECT,
	XP_TE_CONNFAIL,		XP_TE_CTCPGEN,
	XP_TE_CTCPGENC,		XP_TE_CTCPSEND,
	XP_TE_CTCPSND,		XP_TE_DCCCHATABORT,
	XP_TE_DCCCONCHAT,		XP_TE_DCCCHATF,
	XP_TE_DCCCHATOFFER,		XP_TE_DCCCHATOFFERING,
	XP_TE_DCCCHATREOFFER,		XP_TE_DCCCONFAIL,
	XP_TE_DCCGENERICOFFER,		XP_TE_DCCHEAD,
	XP_TE_MALFORMED,		XP_TE_DCCOFFER,
	XP_TE_DCCIVAL,		XP_TE_DCCRECVABORT,
	XP_TE_DCCRECVCOMP,		XP_TE_DCCCONRECV,
	XP_TE_DCCRECVERR,		XP_TE_DCCFILEERR,
	XP_TE_DCCRENAME,		XP_TE_DCCRESUMEREQUEST,
	XP_TE_DCCSENDABORT,		XP_TE_DCCSENDCOMP,
	XP_TE_DCCCONSEND,		XP_TE_DCCSENDFAIL,
	XP_TE_DCCSENDOFFER,		XP_TE_DCCSTALL,
	XP_TE_DCCTOUT,		XP_TE_DELNOTIFY,
	XP_TE_DISCON,		XP_TE_FOUNDIP,
	XP_TE_GENMSG,		XP_TE_IGNOREADD,
	XP_TE_IGNORECHANGE,		XP_TE_IGNOREFOOTER,
	XP_TE_IGNOREHEADER,		XP_TE_IGNOREREMOVE,
	XP_TE_IGNOREEMPTY,		XP_TE_INVITE,
	XP_TE_INVITED,		XP_TE_JOIN,
	XP_TE_KEYWORD,		XP_TE_KICK,
	XP_TE_KILL,		XP_TE_MSGSEND,
	XP_TE_MOTD,		XP_TE_MOTDSKIP,
	XP_TE_NICKCLASH,		XP_TE_NICKFAIL,
	XP_TE_NODCC,		XP_TE_NOCHILD,
	XP_TE_NOTICE,		XP_TE_NOTICESEND,
	XP_TE_NOTIFYEMPTY,		XP_TE_NOTIFYHEAD,
	XP_TE_NOTIFYNUMBER,		XP_TE_NOTIFYOFFLINE,
	XP_TE_NOTIFYONLINE,		XP_TE_OPENDIALOG,
	XP_TE_PART,		XP_TE_PARTREASON,
	XP_TE_PINGREP,		XP_TE_PINGTIMEOUT,
	XP_TE_PRIVMSG,		XP_TE_DPRIVMSG,
	XP_TE_ALREADYPROCESS,		XP_TE_QUIT,
	XP_TE_RAWMODES,		XP_TE_WALLOPS,
	XP_TE_RESOLVINGUSER,		XP_TE_SERVERCONNECTED,
	XP_TE_SERVERERROR,		XP_TE_SERVERLOOKUP,
	XP_TE_SERVNOTICE,		XP_TE_SERVTEXT,
	XP_TE_STOPCONNECT,		XP_TE_TOPIC,
	XP_TE_TOPICDATE,		XP_TE_NEWTOPIC,
	XP_TE_UKNHOST,		XP_TE_USERLIMIT,
	XP_TE_USERSONCHAN,		XP_TE_WHOIS5,
	XP_TE_WHOIS2,		XP_TE_WHOIS6,
	XP_TE_WHOIS_ID,		XP_TE_WHOIS_AUTH,
	XP_TE_WHOIS_REALHOST,		XP_TE_WHOIS4,
	XP_TE_WHOIS4T,		XP_TE_WHOIS1,
	XP_TE_WHOIS3,		XP_TE_UJOIN,
	XP_TE_UPART,		XP_TE_UPARTREASON,
	XP_TE_UKICK,		XP_TE_UINVITE,
	XP_TE_UCHANMSG,		XP_TE_UCHANGENICK,
	NUM_XP
};

==> xchat-2.4.3.tar.bz2: xchat-2.4.3/src/common/textenums.h <==
/* this file is auto generated, edit textevents.in instead! */

enum
{
	XP_TE_ADDNOTIFY,		XP_TE_BANLIST,
	XP_TE_BANNED,		XP_TE_BEEP,
	XP_TE_CHANGENICK,		XP_TE_CHANACTION,
	XP_TE_HCHANACTION,		XP_TE_CHANBAN,
	XP_TE_CHANDATE,		XP_TE_CHANDEHOP,
	XP_TE_CHANDEOP,		XP_TE_CHANDEVOICE,
	XP_TE_CHANEXEMPT,		XP_TE_CHANHOP,
	XP_TE_CHANINVITE,		XP_TE_CHANLISTHEAD,
	XP_TE_CHANMSG,		XP_TE_CHANMODEGEN,
	XP_TE_CHANMODES,		XP_TE_HCHANMSG,
	XP_TE_CHANNOTICE,		XP_TE_CHANOP,
	XP_TE_CHANRMEXEMPT,		XP_TE_CHANRMINVITE,
	XP_TE_CHANRMKEY,		XP_TE_CHANRMLIMIT,
	XP_TE_CHANSETKEY,		XP_TE_CHANSETLIMIT,
	XP_TE_CHANUNBAN,		XP_TE_CHANVOICE,
	XP_TE_CONNECTED,		XP_TE_CONNECT,
	XP_TE_CONNFAIL,		XP_TE_CTCPGEN,
	XP_TE_CTCPGENC,		XP_TE_CTCPSEND,
	XP_TE_CTCPSND,		XP_TE_DCCCHATABORT,
	XP_TE_DCCCONCHAT,		XP_TE_DCCCHATF,
	XP_TE_DCCCHATOFFER,		XP_TE_DCCCHATOFFERING,
	XP_TE_DCCCHATREOFFER,		XP_TE_DCCCONFAIL,
	XP_TE_DCCGENERICOFFER,		XP_TE_DCCHEAD,
	XP_TE_MALFORMED,		XP_TE_DCCOFFER,
	XP_TE_DCCIVAL,		XP_TE_DCCRECVABORT,
	XP_TE_DCCRECVCOMP,		XP_TE_DCCCONRECV,
	XP_TE_DCCRECVERR,		XP_TE_DCCFILEERR,
	XP_TE_DCCRENAME,		XP_TE_DCCRESUMEREQUEST,
	XP_TE_DCCSENDABORT,		XP_TE_DCCSENDCOMP,
	XP_TE_DCCCONSEND,		XP_TE_DCCSENDFAIL,
	XP_TE_DCCSENDOFFER,		XP_TE_DCCSTALL,
	XP_TE_DCCTOUT,		XP_TE_DELNOTIFY,
	XP_TE_DISCON,		XP_TE_FOUNDIP,
	XP_TE_GENMSG,		XP_TE_IGNOREADD,
	XP_TE_IGNORECHANGE,		XP_TE_IGNOREFOOTER,
	XP_TE_IGNOREHEADER,		XP_TE_IGNOREREMOVE,
	XP_TE_IGNOREEMPTY,		XP_TE_INVITE,
	XP_TE_INVITED,		XP_TE_JOIN,
	XP_TE_KEYWORD,		XP_TE_KICK,
	XP_TE_KILL,		XP_TE_MSGSEND,
	XP_TE_MOTD,		XP_TE_MOTDSKIP,
	XP_TE_NICKCLASH,		XP_TE_NICKFAIL,
	XP_TE_NODCC,		XP_TE_NOCHILD,
	XP_TE_NOTICE,		XP_TE_NOTICESEND,
	XP_TE_NOTIFYEMPTY,		XP_TE_NOTIFYHEAD,
	XP_TE_NOTIFYNUMBER,		XP_TE_NOTIFYOFFLINE,
	XP_TE_NOTIFYONLINE,		XP_TE_OPENDIALOG,
	XP_TE_PART,		XP_TE_PARTREASON,
	XP_TE_PINGREP,		XP_TE_PINGTIMEOUT,
	XP_TE_PRIVMSG,		XP_TE_DPRIVMSG,
	XP_TE_ALREADYPROCESS,		XP_TE_QUIT,
	XP_TE_RAWMODES,		XP_TE_WALLOPS,
	XP_TE_RESOLVINGUSER,		XP_TE_SERVERCONNECTED,
	XP_TE_SERVERERROR,		XP_TE_SERVERLOOKUP,
	XP_TE_SERVNOTICE,		XP_TE_SERVTEXT,
	XP_TE_STOPCONNECT,		XP_TE_TOPIC,
	XP_TE_NEWTOPIC,		XP_TE_TOPICDATE,
	XP_TE_UKNHOST,		XP_TE_USERLIMIT,
	XP_TE_USERSONCHAN,		XP_TE_WHOIS_AUTH,
	XP_TE_WHOIS5,		XP_TE_WHOIS2,
	XP_TE_WHOIS6,		XP_TE_WHOIS_ID,
	XP_TE_WHOIS4,		XP_TE_WHOIS4T,
	XP_TE_WHOIS1,		XP_TE_WHOIS_REALHOST,
	XP_TE_WHOIS3,		XP_TE_WHOIS_SPECIAL,
	XP_TE_UJOIN,		XP_TE_UKICK,
	XP_TE_UPART,		XP_TE_UPARTREASON,
	XP_TE_UINVITE,		XP_TE_UCHANMSG,
	XP_TE_UCHANGENICK,
	NUM_XP
};
